@@ -612,6 +612,8 @@ class rms(object):
                                          riderdb.COL_FIRST)
                subhead = self.meet.rdb.getvalue(dbr,
                                          riderdb.COL_LAST)
+        else:
+            cat = u''	# match all riders
         ret = []
         sec = printing.section()
         sec.heading = 'Startlist'
@@ -2087,7 +2089,7 @@ class rms(object):
         if et is not None:
             entry.set_text(et.rawtime())
         else:
-            self.log.info('Invalid elasped time.')
+            self.log.info('Invalid elapsed time.')
 
     def elapsed_dlg(self, addriders=''):
         """Run a 'new start' dialog."""
