@@ -449,7 +449,7 @@ class roadmeet:
     ## Race Menu Callbacks
     def menu_race_run_activate_cb(self, menuitem=None, data=None):
         """Open the event handler."""
-        eh = self.edb.getevent() # only one event
+        eh = self.edb.getfirst() # only one event
         if eh is not None:
             self.open_event(eh)
             self.set_title()
@@ -568,11 +568,13 @@ class roadmeet:
         """Open rider registration dialog."""
         rdlg = registerdlg(self)
         ocb = self.timer.getcb()
+        self.log.debug(u'Read ocb == ' + repr(ocb))
         try:
             self.timer.setcb(rdlg.register_tag)
             rdlg.run()
         finally:
             self.timer.setcb(ocb)
+            self.log.debug(u'Restored ocb == ' + repr(ocb))
         rdlg.destroy()
 
     def menu_data_uscb_activate_cb(self, menuitem, data=None):
@@ -717,6 +719,8 @@ class roadmeet:
 
     def menu_data_results_cb(self, menuitem, data=None):
         """Create live result report and export to MR"""
+        self.saveconfig()
+        self.log.info(u'Meet data saved to ' + repr(self.configpath) + u'.')
         if self.curevent is None:
             return
 
@@ -1212,8 +1216,9 @@ class roadmeet:
                         self.an_cur_bunchcnt,
                         COLOURMAP[self.an_cur_bunchid][0],
                         rftime]
-                elif (rftime < self.an_last_time
-                      or rftime - self.an_last_time < tod.tod('1.12')):
+                elif (self.an_last_time is not None and
+                        (rftime < self.an_last_time
+                         or rftime - self.an_last_time < tod.tod('1.12'))):
                     # Case 2: Same bunch
                     self.an_last_time = rftime
                     self.an_cur_bunchcnt += 1
