@@ -44,13 +44,13 @@ import glib
 from metarace import tod
 
 # System default timy serial port
-DEFPORT = '/dev/ttyS0'
+DEFPORT = '/dev/ttyUSB0'
 
 # Serial baudrate
 THBC_BAUD = 19200
 
-# Photofinish threshold - based on tests at DISC
-THBCPHOTOTHRESH = tod.tod('0.01')
+# Photofinish threshold - ~20cm based on tests at DISC
+THBCPHOTOTHRESH = tod.tod('0.015')
 
 # THbC protocol messages
 ESCAPE = chr(0x1b)
@@ -112,6 +112,10 @@ class thbc(threading.Thread):
         self.log.debug(str(evt))
         return False
 
+    def getcb(self):
+        """Return the current callback function."""
+        return self.__cb
+
     def setcb(self, func=None):
         """Set or clear the event callback."""
         # if func is not callable, gtk mainloop will catch the error
@@ -242,7 +246,8 @@ class thbc(threading.Thread):
                     ## OR provide an alternate callback structure for
                     ## status... probably better and allows for battery
                     ## alerts
-                    self.log.log(RFID_LOG_LEVEL, msg.strip())
+                    #self.log.log(RFID_LOG_LEVEL, msg.strip())
+                    self.log.info(msg.strip())
                 else:
                     self.log.info('Invalid status: ' + repr(msg))
             else:
@@ -345,6 +350,14 @@ class thbc(threading.Thread):
         self.setcb()	# make sure callback in unrefed
         self.log.info('Exiting')
 
+def printtag(t):
+    print(t.refid)
+    return False
+
+def showstatus(data=None):
+    data.status()
+    return True
+
 if __name__ == "__main__":
     import metarace
     import gtk
@@ -363,18 +376,9 @@ if __name__ == "__main__":
         time.sleep(1.0)
         t.start_session()
         t.sync()
-        t.replay('test.sess')
+        t.setcb(printtag)
+        #glib.timeout_add_seconds(2, showstatus, t)
         gtk.main()
-        #ncmd = 0x00
-        #while True:
-            #ncmd += 1
-            #time.sleep(5.0)
-            #if ncmd == 3:
-                #t.replay('testpass.txt')
-            #elif ncmd % 5 == 3:
-                #t.trig(chan='BOX', refid=str(random.randint(70000,89999)))
-            #else:
-                #t.status()
     except:
         t.stop_session()
         t.wait()
