@@ -229,6 +229,10 @@ class wheeltime(threading.Thread):
         self.log.debug(str(evt))
         return False
 
+    def getcb(self):
+        """Return the current callback function."""
+        return self.__cb
+
     def setcb(self, func=None):
         """Set or clear the event callback."""
         # if func is not callable, gtk mainloop will catch the error
